# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.10.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.authenticator_email_stage_request import AuthenticatorEmailStageRequest

class TestAuthenticatorEmailStageRequest(unittest.TestCase):
    """AuthenticatorEmailStageRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AuthenticatorEmailStageRequest:
        """Test AuthenticatorEmailStageRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AuthenticatorEmailStageRequest`
        """
        model = AuthenticatorEmailStageRequest()
        if include_optional:
            return AuthenticatorEmailStageRequest(
                name = '0',
                flow_set = [
                    authentik_client.models.flow_set_request.FlowSetRequest(
                        name = '0', 
                        slug = 'z0', 
                        title = '0', 
                        designation = null, 
                        policy_engine_mode = 'all', 
                        compatibility_mode = True, 
                        layout = 'stacked', 
                        denied_action = null, )
                    ],
                configure_flow = '',
                friendly_name = '',
                use_global_settings = True,
                host = '0',
                port = -2147483648,
                username = '',
                password = '',
                use_tls = True,
                use_ssl = True,
                timeout = -2147483648,
                from_address = '0',
                subject = '0',
                token_expiry = '0',
                template = '0'
            )
        else:
            return AuthenticatorEmailStageRequest(
                name = '0',
        )
        """

    def testAuthenticatorEmailStageRequest(self):
        """Test AuthenticatorEmailStageRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
